==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/ValidateMigrationInputSqlServerSqlMITaskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMITaskInputArgs.builder
import com.pulumi.azurenative.datamigration.kotlin.enums.BackupMode
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Input for task that validates migration input for SQL to Azure SQL Managed Instance
 * @property backupBlobShare SAS URI of Azure Storage Account Container to be used for storing backup files.
 * @property backupFileShare Backup file share information for all selected databases.
 * @property backupMode Backup Mode to specify whether to use existing backup or create new backup.
 * @property selectedDatabases Databases to migrate
 * @property selectedLogins Logins to migrate
 * @property sourceConnectionInfo Information for connecting to source
 * @property targetConnectionInfo Information for connecting to target
 */
public data class ValidateMigrationInputSqlServerSqlMITaskInputArgs(
    public val backupBlobShare: Output<BlobShareArgs>,
    public val backupFileShare: Output<FileShareArgs>? = null,
    public val backupMode: Output<Either<String, BackupMode>>? = null,
    public val selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>,
    public val selectedLogins: Output<List<String>>? = null,
    public val sourceConnectionInfo: Output<SqlConnectionInfoArgs>,
    public val targetConnectionInfo: Output<SqlConnectionInfoArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMITaskInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMITaskInputArgs =
        com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMITaskInputArgs.builder()
            .backupBlobShare(backupBlobShare.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .backupFileShare(backupFileShare?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .backupMode(
                backupMode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .selectedDatabases(
                selectedDatabases.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .selectedLogins(selectedLogins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sourceConnectionInfo(
                sourceConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .targetConnectionInfo(
                targetConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ValidateMigrationInputSqlServerSqlMITaskInputArgs].
 */
@PulumiTagMarker
public class ValidateMigrationInputSqlServerSqlMITaskInputArgsBuilder internal constructor() {
    private var backupBlobShare: Output<BlobShareArgs>? = null

    private var backupFileShare: Output<FileShareArgs>? = null

    private var backupMode: Output<Either<String, BackupMode>>? = null

    private var selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>? = null

    private var selectedLogins: Output<List<String>>? = null

    private var sourceConnectionInfo: Output<SqlConnectionInfoArgs>? = null

    private var targetConnectionInfo: Output<SqlConnectionInfoArgs>? = null

    /**
     * @param value SAS URI of Azure Storage Account Container to be used for storing backup files.
     */
    @JvmName("vesyeyqsqwdyxffp")
    public suspend fun backupBlobShare(`value`: Output<BlobShareArgs>) {
        this.backupBlobShare = value
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("hhqetfswrhffiybi")
    public suspend fun backupFileShare(`value`: Output<FileShareArgs>) {
        this.backupFileShare = value
    }

    /**
     * @param value Backup Mode to specify whether to use existing backup or create new backup.
     */
    @JvmName("lanneedqlkgsnife")
    public suspend fun backupMode(`value`: Output<Either<String, BackupMode>>) {
        this.backupMode = value
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("faofglwrfaqqhihi")
    public suspend
    fun selectedDatabases(`value`: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = value
    }

    @JvmName("brtfwosdmmoeoeev")
    public suspend fun selectedDatabases(
        vararg
        values: Output<MigrateSqlServerSqlMIDatabaseInputArgs>,
    ) {
        this.selectedDatabases = Output.all(values.asList())
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("tcvrlcigdalfhoyt")
    public suspend
    fun selectedDatabases(values: List<Output<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = Output.all(values)
    }

    /**
     * @param value Logins to migrate
     */
    @JvmName("sskyudhetnjoctel")
    public suspend fun selectedLogins(`value`: Output<List<String>>) {
        this.selectedLogins = value
    }

    @JvmName("alyrmliojkgsbnrk")
    public suspend fun selectedLogins(vararg values: Output<String>) {
        this.selectedLogins = Output.all(values.asList())
    }

    /**
     * @param values Logins to migrate
     */
    @JvmName("hxlvqrmmuegwdrsk")
    public suspend fun selectedLogins(values: List<Output<String>>) {
        this.selectedLogins = Output.all(values)
    }

    /**
     * @param value Information for connecting to source
     */
    @JvmName("amoayimrartgjhod")
    public suspend fun sourceConnectionInfo(`value`: Output<SqlConnectionInfoArgs>) {
        this.sourceConnectionInfo = value
    }

    /**
     * @param value Information for connecting to target
     */
    @JvmName("rwuobkfnymccescs")
    public suspend fun targetConnectionInfo(`value`: Output<SqlConnectionInfoArgs>) {
        this.targetConnectionInfo = value
    }

    /**
     * @param value SAS URI of Azure Storage Account Container to be used for storing backup files.
     */
    @JvmName("ggkacwekbpgcyvmu")
    public suspend fun backupBlobShare(`value`: BlobShareArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupBlobShare = mapped
    }

    /**
     * @param argument SAS URI of Azure Storage Account Container to be used for storing backup files.
     */
    @JvmName("djhheifijjrdqitk")
    public suspend fun backupBlobShare(argument: suspend BlobShareArgsBuilder.() -> Unit) {
        val toBeMapped = BlobShareArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backupBlobShare = mapped
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("uqcxnwgeroylcifr")
    public suspend fun backupFileShare(`value`: FileShareArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupFileShare = mapped
    }

    /**
     * @param argument Backup file share information for all selected databases.
     */
    @JvmName("raveuhplicjcilpr")
    public suspend fun backupFileShare(argument: suspend FileShareArgsBuilder.() -> Unit) {
        val toBeMapped = FileShareArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backupFileShare = mapped
    }

    /**
     * @param value Backup Mode to specify whether to use existing backup or create new backup.
     */
    @JvmName("uoqsajmjmxbgmtjy")
    public suspend fun backupMode(`value`: Either<String, BackupMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupMode = mapped
    }

    /**
     * @param value Backup Mode to specify whether to use existing backup or create new backup.
     */
    @JvmName("psboxpcnxsjpmccu")
    public fun backupMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupMode = mapped
    }

    /**
     * @param value Backup Mode to specify whether to use existing backup or create new backup.
     */
    @JvmName("avuhxscneohdvcjd")
    public fun backupMode(`value`: BackupMode) {
        val toBeMapped = Either.ofRight<String, BackupMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupMode = mapped
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("jgrkafgckuyarncv")
    public suspend fun selectedDatabases(`value`: List<MigrateSqlServerSqlMIDatabaseInputArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("vhvvxdugarkukibv")
    public suspend
    fun selectedDatabases(argument: List<suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("vawgvsnahafjhgox")
    public suspend fun selectedDatabases(
        vararg
        argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("kgolbdumacxdwnxh")
    public suspend
    fun selectedDatabases(argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("iymqknssosoerwuw")
    public suspend fun selectedDatabases(vararg values: MigrateSqlServerSqlMIDatabaseInputArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param value Logins to migrate
     */
    @JvmName("emhqoebrkmrcewjk")
    public suspend fun selectedLogins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.selectedLogins = mapped
    }

    /**
     * @param values Logins to migrate
     */
    @JvmName("ukrvdfmyjjhsojdg")
    public suspend fun selectedLogins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedLogins = mapped
    }

    /**
     * @param value Information for connecting to source
     */
    @JvmName("xkleouxpsivhonqd")
    public suspend fun sourceConnectionInfo(`value`: SqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param argument Information for connecting to source
     */
    @JvmName("ieilsapdjmvodxmh")
    public suspend
    fun sourceConnectionInfo(argument: suspend SqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param value Information for connecting to target
     */
    @JvmName("dltsjuhqwipphjpf")
    public suspend fun targetConnectionInfo(`value`: SqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetConnectionInfo = mapped
    }

    /**
     * @param argument Information for connecting to target
     */
    @JvmName("pkcomjqkotatwtpd")
    public suspend
    fun targetConnectionInfo(argument: suspend SqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetConnectionInfo = mapped
    }

    internal fun build(): ValidateMigrationInputSqlServerSqlMITaskInputArgs =
        ValidateMigrationInputSqlServerSqlMITaskInputArgs(
            backupBlobShare = backupBlobShare ?: throw PulumiNullFieldException("backupBlobShare"),
            backupFileShare = backupFileShare,
            backupMode = backupMode,
            selectedDatabases = selectedDatabases ?: throw PulumiNullFieldException("selectedDatabases"),
            selectedLogins = selectedLogins,
            sourceConnectionInfo = sourceConnectionInfo ?: throw
                PulumiNullFieldException("sourceConnectionInfo"),
            targetConnectionInfo = targetConnectionInfo ?: throw
                PulumiNullFieldException("targetConnectionInfo"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/ValidateMigrationInputSqlServerSqlMITaskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMITaskInputArgs.builder
import com.pulumi.azurenative.datamigration.kotlin.enums.BackupMode
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Input for task that validates migration input for SQL to Azure SQL Managed Instance
 * @property backupBlobShare SAS URI of Azure Storage Account Container to be used for storing backup files.
 * @property backupFileShare Backup file share information for all selected databases.
 * @property backupMode Backup Mode to specify whether to use existing backup or create new backup.
 * @property selectedDatabases Databases to migrate
 * @property selectedLogins Logins to migrate
 * @property sourceConnectionInfo Information for connecting to source
 * @property targetConnectionInfo Information for connecting to target
 */
public data class ValidateMigrationInputSqlServerSqlMITaskInputArgs(
    public val backupBlobShare: Output<BlobShareArgs>,
    public val backupFileShare: Output<FileShareArgs>? = null,
    public val backupMode: Output<Either<String, BackupMode>>? = null,
    public val selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>,
    public val selectedLogins: Output<List<String>>? = null,
    public val sourceConnectionInfo: Output<SqlConnectionInfoArgs>,
    public val targetConnectionInfo: Output<SqlConnectionInfoArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMITaskInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMITaskInputArgs =
        com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMITaskInputArgs.builder()
            .backupBlobShare(backupBlobShare.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .backupFileShare(backupFileShare?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .backupMode(
                backupMode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .selectedDatabases(
                selectedDatabases.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .selectedLogins(selectedLogins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sourceConnectionInfo(
                sourceConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .targetConnectionInfo(
                targetConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ValidateMigrationInputSqlServerSqlMITaskInputArgs].
 */
@PulumiTagMarker
public class ValidateMigrationInputSqlServerSqlMITaskInputArgsBuilder internal constructor() {
    private var backupBlobShare: Output<BlobShareArgs>? = null

    private var backupFileShare: Output<FileShareArgs>? = null

    private var backupMode: Output<Either<String, BackupMode>>? = null

    private var selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>? = null

    private var selectedLogins: Output<List<String>>? = null

    private var sourceConnectionInfo: Output<SqlConnectionInfoArgs>? = null

    private var targetConnectionInfo: Output<SqlConnectionInfoArgs>? = null

    /**
     * @param value SAS URI of Azure Storage Account Container to be used for storing backup files.
     */
    @JvmName("npovffrphmkeclhm")
    public suspend fun backupBlobShare(`value`: Output<BlobShareArgs>) {
        this.backupBlobShare = value
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("abbrjnuxqngsbcbd")
    public suspend fun backupFileShare(`value`: Output<FileShareArgs>) {
        this.backupFileShare = value
    }

    /**
     * @param value Backup Mode to specify whether to use existing backup or create new backup.
     */
    @JvmName("iramkflxlrswsnhd")
    public suspend fun backupMode(`value`: Output<Either<String, BackupMode>>) {
        this.backupMode = value
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("uatmwxfatbrlwurm")
    public suspend
    fun selectedDatabases(`value`: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = value
    }

    @JvmName("rdwbdraplqhknbxk")
    public suspend fun selectedDatabases(
        vararg
        values: Output<MigrateSqlServerSqlMIDatabaseInputArgs>,
    ) {
        this.selectedDatabases = Output.all(values.asList())
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("leokckmmtswhkvsr")
    public suspend
    fun selectedDatabases(values: List<Output<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = Output.all(values)
    }

    /**
     * @param value Logins to migrate
     */
    @JvmName("jdumrpqmcjgjdfrt")
    public suspend fun selectedLogins(`value`: Output<List<String>>) {
        this.selectedLogins = value
    }

    @JvmName("nppchywqokmgnbnh")
    public suspend fun selectedLogins(vararg values: Output<String>) {
        this.selectedLogins = Output.all(values.asList())
    }

    /**
     * @param values Logins to migrate
     */
    @JvmName("irkhttomxfpiyiok")
    public suspend fun selectedLogins(values: List<Output<String>>) {
        this.selectedLogins = Output.all(values)
    }

    /**
     * @param value Information for connecting to source
     */
    @JvmName("qyogxmuiyudiwnyi")
    public suspend fun sourceConnectionInfo(`value`: Output<SqlConnectionInfoArgs>) {
        this.sourceConnectionInfo = value
    }

    /**
     * @param value Information for connecting to target
     */
    @JvmName("lvhofpspfwgfbrbk")
    public suspend fun targetConnectionInfo(`value`: Output<SqlConnectionInfoArgs>) {
        this.targetConnectionInfo = value
    }

    /**
     * @param value SAS URI of Azure Storage Account Container to be used for storing backup files.
     */
    @JvmName("kqswmsytdtudsvmm")
    public suspend fun backupBlobShare(`value`: BlobShareArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupBlobShare = mapped
    }

    /**
     * @param argument SAS URI of Azure Storage Account Container to be used for storing backup files.
     */
    @JvmName("vxgftokxjbgswvog")
    public suspend fun backupBlobShare(argument: suspend BlobShareArgsBuilder.() -> Unit) {
        val toBeMapped = BlobShareArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backupBlobShare = mapped
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("jamajuucmhjfoivs")
    public suspend fun backupFileShare(`value`: FileShareArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupFileShare = mapped
    }

    /**
     * @param argument Backup file share information for all selected databases.
     */
    @JvmName("dxfeuulygejytmvt")
    public suspend fun backupFileShare(argument: suspend FileShareArgsBuilder.() -> Unit) {
        val toBeMapped = FileShareArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backupFileShare = mapped
    }

    /**
     * @param value Backup Mode to specify whether to use existing backup or create new backup.
     */
    @JvmName("icynpwtawlkchtwt")
    public suspend fun backupMode(`value`: Either<String, BackupMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupMode = mapped
    }

    /**
     * @param value Backup Mode to specify whether to use existing backup or create new backup.
     */
    @JvmName("gqcsaqoppaorxann")
    public fun backupMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupMode = mapped
    }

    /**
     * @param value Backup Mode to specify whether to use existing backup or create new backup.
     */
    @JvmName("apggaacvixaeabpd")
    public fun backupMode(`value`: BackupMode) {
        val toBeMapped = Either.ofRight<String, BackupMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupMode = mapped
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("wfsalhshnaqdmgxc")
    public suspend fun selectedDatabases(`value`: List<MigrateSqlServerSqlMIDatabaseInputArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("amhpbgwfsvergoaa")
    public suspend
    fun selectedDatabases(argument: List<suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("rpmyyegsxrdeaqke")
    public suspend fun selectedDatabases(
        vararg
        argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("ldjaijppuiywkhmg")
    public suspend
    fun selectedDatabases(argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("simwbvuimhahmwhd")
    public suspend fun selectedDatabases(vararg values: MigrateSqlServerSqlMIDatabaseInputArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param value Logins to migrate
     */
    @JvmName("jhacokganduyftbr")
    public suspend fun selectedLogins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.selectedLogins = mapped
    }

    /**
     * @param values Logins to migrate
     */
    @JvmName("pfynmrrlbrjbdlrq")
    public suspend fun selectedLogins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedLogins = mapped
    }

    /**
     * @param value Information for connecting to source
     */
    @JvmName("glsjwbrvmwlqclha")
    public suspend fun sourceConnectionInfo(`value`: SqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param argument Information for connecting to source
     */
    @JvmName("yxhdroktlouaavav")
    public suspend
    fun sourceConnectionInfo(argument: suspend SqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param value Information for connecting to target
     */
    @JvmName("mtxlovqdhpafyurk")
    public suspend fun targetConnectionInfo(`value`: SqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetConnectionInfo = mapped
    }

    /**
     * @param argument Information for connecting to target
     */
    @JvmName("hwdvntvoqngiauox")
    public suspend
    fun targetConnectionInfo(argument: suspend SqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetConnectionInfo = mapped
    }

    internal fun build(): ValidateMigrationInputSqlServerSqlMITaskInputArgs =
        ValidateMigrationInputSqlServerSqlMITaskInputArgs(
            backupBlobShare = backupBlobShare ?: throw PulumiNullFieldException("backupBlobShare"),
            backupFileShare = backupFileShare,
            backupMode = backupMode,
            selectedDatabases = selectedDatabases ?: throw PulumiNullFieldException("selectedDatabases"),
            selectedLogins = selectedLogins,
            sourceConnectionInfo = sourceConnectionInfo ?: throw
                PulumiNullFieldException("sourceConnectionInfo"),
            targetConnectionInfo = targetConnectionInfo ?: throw
                PulumiNullFieldException("targetConnectionInfo"),
        )
}
